@@ -4,9 +4,10 @@ use crate::vcs::determine_browser_url;
 use crate::{get_committer, parseaddr};
 use debian_control::control::Source;
 
+use breezyshim::branch::Branch;
 use breezyshim::error::Error as BrzError;
 use breezyshim::forge::create_project;
-use breezyshim::tree::WorkingTree;
+use breezyshim::workingtree::PyWorkingTree;
 use breezyshim::workspace::check_clean_tree;
 use debian_control::vcs::ParsedVcs;
 use std::path::Path;
@@ -27,6 +28,8 @@ pub fn update_control_for_vcs_url(
             breezyshim::foreign::VcsType::Cvs => "Vcs-Cvs",
             breezyshim::foreign::VcsType::Darcs => "Vcs-Darcs",
             breezyshim::foreign::VcsType::Fossil => "Vcs-Fossil",
+            breezyshim::foreign::VcsType::Arch => "Vcs-Arch",
+            breezyshim::foreign::VcsType::Svk => "Vcs-Svk",
         },
         vcs_url,
     );
@@ -80,7 +83,7 @@ impl std::fmt::Display for Error {
 
 /// Update the official VCS location for the given source package.
 pub fn update_official_vcs(
-    wt: &WorkingTree,
+    wt: &dyn PyWorkingTree,
     subpath: &Path,
     repo_url: Option<&Url>,
     branch: Option<&str>,
@@ -154,7 +157,7 @@ pub fn update_official_vcs(
         subpath: subpath.map(|p| p.to_string_lossy().to_string()),
     };
     update_control_for_vcs_url(&mut source, branch.vcs_type(), &vcs_url.to_string());
-    let parsed_vcs = vcs_url.clone();
+    let parsed_vcs = vcs_url;
 
     let committer = committer.map_or_else(|| get_committer(wt), |s| s.to_string());
 
